@@ -11,6 +11,7 @@ import ConfigParser
 import os, os.path
 
 import data
+import filter_data #filter
 import records #record data
 
 
@@ -99,9 +100,9 @@ def LoadConfig():
         config.set('main', 'derivation_offset', str(data.derivation_offset))
 
     try:
-        data.filterScale = config.getint('main', 'filterScale')
+        data.FilterScale = config.getint('main', 'FilterScale')
     except:
-        config.set('main', 'filterScale', str(data.filterScale))
+        config.set('main', 'FilterScale', str(data.FilterScale))
 
     try:
         tmp=config.get('main', 'user')
@@ -110,9 +111,9 @@ def LoadConfig():
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
 
     try:
-        data.lastlogfile = config.get('main', 'lastlogfile')
+        data.LastRecord = config.get('main', 'LastRecord')
     except:
-        config.set('main', 'lastlogfile', str(data.lastlogfile))
+        config.set('main', 'LastRecord', str(data.LastRecord))
 
     try:
         tmp = config.get('main', 'OfflineMode')
@@ -247,4 +248,4 @@ def Index2Tuple(Index):
 #    t2=1000*(now-data.passed_time2)
 #    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
 #
-#    data.passed_time2 = time.time()
+#    data.passed_time2 = time.time()
\ No newline at end of file
