@@ -32,8 +32,8 @@ from dbus.mainloop.qt import DBusQtMainLoop
 
 
 
-import records #record data
 import data #own data
+import records #record data
 
 
 #own functions
@@ -74,6 +74,11 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
+#ar=[1, 1]
+#print ar
+#mylib.test_shedskin(ar)
+#print ar
+#exit
 
 ###########################################################################
 ## Main function
@@ -141,7 +146,7 @@ def main():
 
     #chek if module is available and could get loaded
     if(MyLib_Imported==True): #module is loaded
-#        print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
+        print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
         if(mylib.IsCompiled()==False): #module is not compiled
             txt= "SleepAnalyser:\nThe compiled module mylib.so could not get loaded! Please check if there is a never version "+ \
                      "or inform the maintainer about it! SleepAnalyser will still work, " + \
@@ -296,9 +301,9 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             #change directly to view screen
 #            DeleteAlarm() #delete Alarm if existing
 #            records.AlarmIsSet=False
-            data.lastlogfile=data.logfilename #set to corrent file for viewwindow
-            config.set('main', 'lastlogfile', str(data.lastlogfile))
-            print "Show record in ViewWindow:",  data.lastlogfile
+            data.LastRecord=data.logfilename #set to corrent file for viewwindow
+            config.set('main', 'LastRecord', str(data.LastRecord))
+            print "Show record in ViewWindow:",  data.LastRecord
             StartWindow.ShowViewWindow()
             RecordWindow.hide()
 
@@ -635,8 +640,8 @@ class frmStartWindow(QMainWindow):
         LoadFileList()
         data.arrLogFileIndex=len(data.arrLogFiles)-1 #no file selected, show latest
 
-        if os.path.exists(data.logfolder+data.lastlogfile):
-            data.logfilename=data.lastlogfile
+        if os.path.exists(data.logfolder+data.LastRecord):
+            data.logfilename=data.LastRecord
         else:
             l=len(data.arrLogFiles)
             if(l>0):
@@ -654,7 +659,7 @@ class frmStartWindow(QMainWindow):
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
 
 
-        ViewWindow.ShowLogFile()
+        ViewWindow.ShowRecord()
 
 #        if(data.logfilename!=""):
 #            ViewWindow.show()
@@ -969,9 +974,9 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
-        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextLogFile)
-        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
-        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
+        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextRecord)
+        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastRecord)
+        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteRecord)
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         QtCore.QObject.connect(self.ui.bOpenDate, QtCore.SIGNAL("clicked()"), self.OpenDate)
@@ -1076,7 +1081,7 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     ##
     ###########################################################################
-    def ShowLogFile(self): ##(Class ViewWindow)
+    def ShowRecord(self): ##(Class ViewWindow)
         global app
 
         self.ui.lblStart.setText("")
@@ -1144,18 +1149,18 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     ##
     ###########################################################################
-    def NextLogFile(self): ##(Class ViewWindow)
+    def NextRecord(self): ##(Class ViewWindow)
         data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
-        self.ShowLogFile()
+        self.ShowRecord()
 
     ###########################################################################
     ##
     ###########################################################################
-    def LastLogFile(self): ##(Class ViewWindow)
+    def LastRecord(self): ##(Class ViewWindow)
         data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
-        self.ShowLogFile()
+        self.ShowRecord()
 
 
     ###########################################################################
@@ -1248,7 +1253,7 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     ##
     ###########################################################################
-    def DeleteLogFile(self): ##(Class ViewWindow)
+    def DeleteRecord(self): ##(Class ViewWindow)
         self.ui.lblStatus.setText("Delete file...")
         self.ui.lblStatus.show()
         reply = QtGui.QMessageBox.question(self, _("Delete Record?"), _("Are you sure you want to delete this record:")+"\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
@@ -1272,7 +1277,7 @@ class frmViewWindow(QMainWindow):
                 data.logfilename=tmp2[l-1]
                 data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
-            self.ShowLogFile()
+            self.ShowRecord()
             self.UpdateScreen()
         self.ui.lblStatus.hide()
         self.StatisticsCanvas.show()
@@ -1303,7 +1308,7 @@ class frmViewWindow(QMainWindow):
         data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
         print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         LoadFileList()
-        self.ShowLogFile()
+        self.ShowRecord()
         self.ui.lblStatus.hide()
         self.StatisticsCanvas.show()
 
@@ -1491,8 +1496,8 @@ class frmConfigWindow(QMainWindow):
         self.ui.SlrYscale_Movement.setValue(int(data.Yscale))
 
 
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep pattern (blue):")+" "+str(data.filterScale))
-        self.ui.SlrYscale_Sleep.setValue(int(data.filterScale))
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep pattern (blue):")+" "+str(data.FilterScale))
+        self.ui.SlrYscale_Sleep.setValue(int(data.FilterScale))
 
 
 
@@ -1545,7 +1550,7 @@ class frmConfigWindow(QMainWindow):
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
         config.set('main', 'Yscale', str(data.Yscale))
-        config.set('main', 'filterScale', str(data.filterScale))
+        config.set('main', 'FilterScale', str(data.FilterScale))
 
 
 
@@ -1580,8 +1585,8 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def YscaleSliderMoved_Sleep(self): ##(Class ConfigWindow)
         x=self.ui.SlrYscale_Sleep.value()
-        data.filterScale=int(x)
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.filterScale))
+        data.FilterScale=int(x)
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
 
 
 
@@ -1644,7 +1649,7 @@ class frmDateWindow(QMainWindow):
         data.logfilename=data.LogFileSelectedDate
         print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         DateWindow.hide()
-        ViewWindow.ShowLogFile()
+        ViewWindow.ShowRecord()
 
 
 
@@ -1928,9 +1933,9 @@ class frmAskForKeepWindow(QMainWindow):
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
-        data.lastlogfile=data.logfilename #set to corrent file for viewwindow
-        config.set('main', 'lastlogfile', str(data.lastlogfile))
-        print "Show record in ViewWindow:",  data.lastlogfile
+        data.LastRecord=data.logfilename #set to corrent file for viewwindow
+        config.set('main', 'LastRecord', str(data.LastRecord))
+        print "Show record in ViewWindow:",  data.LastRecord
         RecordWindow.hide()
         self.hide()
         StartWindow.ShowViewWindow()
